# Single Sign-On (SSO)
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/single-sign-on-sso#overview)
  * [Authentication Flow](https://help.sap.com/docs/leanix/ea/single-sign-on-sso#authentication-flow)
  * [Requirements for Identity Providers](https://help.sap.com/docs/leanix/ea/single-sign-on-sso#requirements-for-identity-providers)
  * [Example Identity Providers](https://help.sap.com/docs/leanix/ea/single-sign-on-sso#example-identity-providers)
  * [Configuring SSO](https://help.sap.com/docs/leanix/ea/single-sign-on-sso#configuring-sso)
  * [Managing User Roles with SSO](https://help.sap.com/docs/leanix/ea/single-sign-on-sso#managing-user-roles-with-sso)
  * [Managing User Roles Within SAP LeanIX](https://help.sap.com/docs/leanix/ea/single-sign-on-sso#managing-user-roles-within-sap-leanix)
  * [Managing User Roles Within the Identity Provider](https://help.sap.com/docs/leanix/ea/single-sign-on-sso#managing-user-roles-within-the-identity-provider)


View all
Learn how to configure single sign-on (SSO) with SAP LeanIX.
